abacusai.chatllm_computer_status — AbacusAI documentation

# abacusai.chatllm_computer_status

## Classes

`ChatllmComputerStatus` | ChatLLM Computer Status

## Module Contents

class abacusai.chatllm_computer_status.ChatllmComputerStatus(client, computerId=None, vncEndpoint=None, computerStarted=None, restartRequired=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  ChatLLM Computer Status

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - computerId (str) – The ID of the computer, it can be a deployment_conversation_id or a computer_id (TODO: add separate field for deployment_conversation_id)

    - vncEndpoint (str) – The VNC endpoint of the computer

    - computerStarted (bool) – Whether the computer has started

    - restartRequired (bool) – Whether the computer needs to be restarted

  computer_id = None
  vnc_endpoint = None
  computer_started = None
  restart_required = None
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict